whatsthedamage.view package
===========================

.. automodule:: whatsthedamage.view
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

whatsthedamage.view.forms module
--------------------------------

.. automodule:: whatsthedamage.view.forms
   :members:
   :show-inheritance:
   :undoc-members:

whatsthedamage.view.row\_printer module
---------------------------------------

.. automodule:: whatsthedamage.view.row_printer
   :members:
   :show-inheritance:
   :undoc-members:
